@@ -18,4 +18,6 @@ class KerberosSecretType(enum.Enum):
 	TDES = 'TDES'
 	CCACHE = 'CCACHE'
 	KEYTAB = 'KEYTAB'
-	KIRBI = 'KIRBI'
\ No newline at end of file
+	KIRBI = 'KIRBI'
+	PFX = 'PFX'
+	PEM = 'PEM'
\ No newline at end of file
